function Q_beta()
% function [vbprb]=Q_beta(vbprb, g_vals)
% updates the regression parameter distribution for all subsets and indicator values
% IN:
% vbprb:    a vbprb object as constructed by vbprobot.
% g_vals:   other parameters that are relevant for updating the model parameters
% OUT:
% vbprb with all regression parameter distributions updated.
%
% (C) P. Sykacek 2005
% modification: we have now a loop over systems.
% mod 2006 : global vbprb and g_vals

global vbprb;
global g_vals;
nsys=length(vbprb.sys);
for sctr=1:nsys
    nsubsets=length(vbprb.sys(sctr).g_mdls);
    % nr indicators
    n_I=length(vbprb.sys(sctr).g_mdls(1).i_mdl);
    n=1;
    while n <= nsubsets % over all subsets
        m=1;
        while m <= n_I  % and indicator variables
            % calculate the Ig contribution to the neg. free energy
            % get some values into local store (shorter equns)
            indim=vbprb.sys(sctr).g_mdls(n).i_mdl(m).n_in;
            mz=vbprb.sys(sctr).latmeans(:,n,m);
            lz=vbprb.gamma*ones(size(mz));
            trg=g_vals(sctr).trg;
            in=g_vals(sctr).g_in{n,m}; 
            [Ez]=exp_z(mz, lz, trg)';
            g_p=vbprb.sys(sctr).g_p(1:indim);
            h_p=vbprb.sys(sctr).h_p(1:indim);        
            Lmb_p=diag(g_p./h_p);
            vbprb.sys(sctr).g_mdls(n).i_mdl(m).P=Lmb_p+vbprb.gamma*in'*in;
            vbprb.sys(sctr).g_mdls(n).i_mdl(m).C=pinv(vbprb.sys(sctr).g_mdls(n).i_mdl(m).P);
            vbprb.sys(sctr).g_mdls(n).i_mdl(m).beta=vbprb.sys(sctr).g_mdls(n).i_mdl(m).C*...
                vbprb.gamma*sum(in'.*Ez(ones(indim,1),:),2);
            %C=vbprb.g_mdls(n).i_mdl(m).C
            %beta=vbprb.g_mdls(n).i_mdl(m).beta
            m=m+1;
        end
        n=n+1;
    end
end