function get_FI()
% function [allFI, sysFI]=get_FI(vbprb, g_vals)
% calculates the part of the negative free energy that
% is contributed by each (g,Ig) pair. It is obtained after maximising 
% the free energy w.r.t. all other parameters.
% IN:
% vbprb:   a vbprb object as is generated by vbprobit
% OUT:
% allFI:    [nsubsets x 2] entries, each containing the
%           negative free energy contribution of a (g x Ig) pair.
%
% (C) P. Sykacek 2005
% new version: change log(P_I) to psi_I (and take uncertainty about indicator prior 
% into consideration). The multo systems version here has an additional loop over systems.
% We have a global contribution from the indicator posterior. All others are system specific.
%
% modification for "agreement score" (KL divergence): get marginal
% likelihood for every system in s_tmp and write to sysFI.
% modification for global vbprb, g_vals, allFI and sysFI in 07 2006
global vbprb;
global g_vals;
global allFI;
global sysFI;

% nr subsets
nsubsets=length(vbprb.sys(1).g_mdls);
% nr indicators
n_I=length(vbprb.sys(1).g_mdls(1).i_mdl);
allFI=zeros(nsubsets, n_I);
psi_vals=psi(vbprb.i_Postcnt)-psi(sum(vbprb.i_Postcnt));
nsys=length(vbprb.sys);
sysFI=zeros(nsubsets, n_I, nsys);
n=1;
while n <= nsubsets % over all subsets
    m=1;
    while m <= n_I  % and indicator variables
        % calculate the Ig contribution to the neg. free energy 
        % global posterior counts contribution:
        f_tmp=psi_vals(m);
        % now loop over systems:
        for sctr=1:nsys
            % get some values into local store (shorter equns)
            indim=vbprb.sys(sctr).g_mdls(n).i_mdl(m).n_in;
            bt_p=vbprb.sys(sctr).g_mdls(n).i_mdl(m).beta;
            bt_P=vbprb.sys(sctr).g_mdls(n).i_mdl(m).P;
            bt_C=vbprb.sys(sctr).g_mdls(n).i_mdl(m).C;
            z_p=vbprb.sys(sctr).latmeans(:,n,m);
            in=g_vals(sctr).g_in{n,m};
            g_p=vbprb.sys(sctr).g_p(1:indim);
            h_p=vbprb.sys(sctr).h_p(1:indim);
            %g_p=vbprb.sys(sctr).g_mdls(n).g_p(1:indim);
            %h_p=vbprb.sys(sctr).g_mdls(n).h_p(1:indim);
            %P_I=vbprb.sys(sctr).g_mdls(n).i_Prio(m);
            %psi_I=psi(vbprb.sys(sctr).g_mdls(n).i_Postcnt(m))-psi(sum(vbprb.sys(sctr).g_mdls(n).i_Postcnt));
            % prior precision over regression params
            Lmb_p=diag(g_p./h_p);
            s_tmp=0.5*(sum(psi(g_p)-log(h_p))-bt_p'*Lmb_p*bt_p-trace(bt_C*Lmb_p));
            s_tmp=s_tmp+0.5*(indim - log(det(bt_P)));
            sd=sqrt(ones(size(z_p))/vbprb.gamma);
            [P_a]=bprb_normcdf(g_vals(sctr).an, z_p, sd);
            [P_b]=bprb_normcdf(g_vals(sctr).bn, z_p, sd);
            Pd=P_b-P_a;
            if (any(Pd < eps))
                P_a
                P_b
                g_vals(sctr).an
                g_vals(sctr).bn
                z_p
                sd
                error('stop');
            end
            s_tmp=s_tmp+sum(log(Pd)-0.5*vbprb.gamma*sum(in*bt_C.*in, 2));
            sysFI(n, m, sctr)=s_tmp;
            f_tmp=f_tmp+s_tmp;
        end
        allFI(n, m)=f_tmp;
        m=m+1;
    end
    n=n+1;
end