function [P]=predsingle(gamma, Qw, in)
% function [P]=predsingle(gamma, Qw, in)
% predicts probit based probabilities for class 1 conditional on inputs.
% Note that predictions use the approximate posterior
% provided by Qw. Except for using the approximate posterior, 
% the calculations are exact (and thus different to the approach 
% chosen for parameter inference).
%
% IN:
% gamma:    precision of the Gaussian in the probit link.
% Qw:       approximate parameter distribution of the model.
% in:       corresponding regressors projected onto the nonlinear basis (if applicable)
%
% OUT:
% P:        posterior probabilities for class 1 (in a 2 class case).
% 
% (C) P. Sykacek 2003, 2005

latstd=sqrt(1./gamma+sum((in*Qw.C).*in,2));
allarg=-in*Qw.beta./latstd;
P=cdf_stdGauss(allarg);