function theseP=vbprb_predone(sysno, subsno, allexpr)
% function theseP=vbprb_predone(vbprb, sysno, subsno, allexpr)
% predicts Probabilities for class one for one
% system and subset number. This new function was added to
% the code since we have to treat the reference subset differently.
% IN:
%
% vbprb    - a fuly infered vbprb object.
% sysno    - system number
% subsno   - subset number
% allexpr  - all expression values of the corresponding system.
%
% OUT:
% theseP   - predicted probabilities of class one for all samples in allexpr.
% 
% (C) P. Sykacek 2005
% mod 2006: global vbprb;

global vbprb;

% if the subset is not the reference model we predict from the model that
% represents the corresponding subset (I_n == 1 hence the second of
% g_mdls).
if subsno ~= vbprb.refsubspos
    if subsno>vbprb.refsubspos % then we need to subtract by one since the reference subset has been
                               % removed from the subsets and thus all larger number models are one index less! 
        subsno=subsno-1;
    end
    in = getpredinputs(vbprb.basisf, vbprb.sys(sysno).g_mdls(subsno).i_mdl(2).K,...
        vbprb.sys(sysno).g_mdls(subsno).i_mdl(2).subs, allexpr);
    theseP=predsingle(vbprb.gamma, vbprb.sys(sysno).g_mdls(subsno).i_mdl(2), in);
else % here we have the case where we predict from the reference subset.
    % we average over the 10 % of all reference parameters (they appear multiple)
    % and are updated independently.
    maxdx=ceil(0.1*length(vbprb.sys(sysno).g_mdls));
    idx=randperm(length(vbprb.sys(sysno).g_mdls));
    idx=idx(1:maxdx);
    in = getpredinputs(vbprb.basisf, vbprb.sys(sysno).g_mdls(idx(1)).i_mdl(1).K,...
        vbprb.sys(sysno).g_mdls(idx(1)).i_mdl(1).subs, allexpr);
    theseP=predsingle(vbprb.gamma, vbprb.sys(sysno).g_mdls(idx(1)).i_mdl(1), in);
    for n=2:maxdx

        in = getpredinputs(vbprb.basisf, vbprb.sys(sysno).g_mdls(idx(n)).i_mdl(1).K,...
            vbprb.sys(sysno).g_mdls(idx(n)).i_mdl(1).subs, allexpr);
        theseP=theseP+predsingle(vbprb.gamma, vbprb.sys(sysno).g_mdls(idx(n)).i_mdl(1), in);
    end
    theseP=theseP/maxdx;
end